@@ -15,16 +15,12 @@ class Plugin : public KontactInterface::Plugin
     Q_OBJECT
 
 public:
-    Plugin(KontactInterface::Core *core, const QVariantList &);
+    Plugin(KontactInterface::Core *core, const KPluginMetaData &data, const QVariantList &);
 
     int weight() const override { return 449; }
 
 protected:
-#if KONTACTINTERFACE_VERSION >= QT_VERSION_CHECK(5, 14, 42)
     KParts::Part *createPart() override;
-#else
-    KParts::ReadOnlyPart *createPart() override;
-#endif
 };
 
 #endif
